from typing import overload

def RedirectLogOutput()->None:
    """Redirects all print, stdout and stderr outputs to the system log. 
    This can be viewed in the web interface under "Diagnostics system events".
    """

   
def setSystemLog (group:str,logtext:str,status:int)->None:
    """ Writes an entry to the system log. 
        This can be viewed in the web interface under "Diagnostic system events".
    """

def Breakpoint()->None:
   """ Sets a breakpoint. 
       When the breakpoint is reached, the debugger is activated. 
       The debugger can be accessed via a web browser using port 5555.
    """
@overload
def OPCReadVar(node:str) -> object :
    """Function for reading OPC nodes.
         Return value: Scalar value or string variable
    """
@overload
def OPCReadVar(ns:int,node:int)->object :
    """Function for reading OPC nodes.
         Return value: Scalar value or string variable
    """
@overload
def OPCReadVar(extern_server:str,node:str) -> object :
    """Function for reading OPC nodes from external server.
         Return value: Scalar value or string variable
    """

@overload
def OPCWriteVar(node:str,var:float)->int:
    """ Function for writing scalar nodes .
        The OPC type is determined automatically from the target variable.
    """
@overload
def OPCWriteVar(node:str,var:str)->int:
    """ Function for writing string nodes.
        The OPC type is determined automatically from the target variable.
    """
@overload
def OPCWriteVar(node:str,var:object)->int:
    """ Function for writing scalar nodes or string nodes.
        The OPC type is determined automatically from the target variable.
    """
@overload
def OPCWriteVar(extern_server:str,node:str,var:object)->int:
    """ Function for writing scalar nodes or string nodes to external eerver.
        The OPC type is determined automatically from the target variable.
    """
@overload
def OPCWriteVar(ns:int,node:int,var:object)->int:
    """ Function for writing scalar nodes or string nodes.
        The OPC type is determined automatically from the target variable.
    """

def monitor(node:str,monitor_function_name:str,intervall:float,triggermode:int,deadband:float)->int:
    """
        When the OPC variable "Node" is changed, the "Monitor function" is called up.
        "Interval": determines the sampling interval in ms.
        "Trigger mode" :
            0 = is always triggered
            1=Trigger on value change
            2=Trigger on rising edge
            3=Trigger on falling edge
        "Deadband": determines the minimum value change that leads to the trigger The monitor function contains an input parameter with the read value.    
    """

def OPCResult()->int:
    """
        Returns the result of the OPCReadVar, OPCWriteVar and OPCCallMethod functions.
        Parameters:
            Return value: 0=successful
    """

def OPCConnectedServers()->object:
    """
        This function returns a list of the connected OPC servers.
        With this function you can easily determine the complete name of an external server.
    """

@overload
def OPCCallMethod(extern_server:str,object_node:str,method_node:str)->int:
    """
        Calling a method without parameters
        Parameters:
            ExternalServer
            object-nodeid : Nodename of the parent object
            method-nodeid : Nodename of the method
            return : Result (0=successful)
    """
@overload
def OPCCallMethod(extern_server:str,object_node:str,method_node:str,parameters:[])->int:
    """
        Calling a method with parameters
        Parameters:
            ExternalServer
            object-nodeid : Nodename of the parent object
            method-nodeid : Nodename of the method
            parameters : Parameters
            return : Result (0=successful)
    """

def get_namespace(name:str) ->int:
    """
        This function returns the namespace number. 
        The namespace name is specified as the input parameter. 
        The namespace name can be found in the UAExpert under Server
    """    

def OPCError (error_code:int)->None:
    """
        Aborts execution if the error code is not 0 and returns the OPC error code.
            If a 0 is passed, the function has no effect.    
    """

def method(ns:int,node:object,method_function:str)->None:
    """
        Links a method defined in an imported nodeset with a Python function.
        Parameters: 
            * ns : Namespace number
            * node : Nodename or numeric ID
            * Function that is called when the method is called
    """

def variable(ns:int,node:object,read_function:str,write_function:str)->None:
    """
        Links a variable defined in an imported nodeset with a Python function.
        Parameters:
            ns : Namespace number
            node : Nodename or numeric ID
            read function : Function that is called when the variable is read
                The function contains no input parameter and one output parameter.
            write function : Function that is called when the variable is written
                The function contains an input parameter and no output parameter.
    """

def map(ns:int, id:object, ns_destination:str, id_destination:str )->None:
    """
        Connects the OPC variable (ns,id) with another variable.
        The advantage of this function is that no Python program is run during reading and writing. (faster)
        Attention: The data types must match!
        Parameters:
            ns : Namespace number
            node : Nodename or numeric ID
            ns_destination : Namespace number of the destination variable
            id_destination : Nodename or numeric ID of the target variable
            node : Nodeid of the variable in another namespace
            Return value: 1=successful, -1=not successful    
    """

    
